@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 import { createApplicationLink } from "../../../src-web/definitions/hcm-applications";
 
@@ -33,7 +34,8 @@ const query_data1 = {
       status: "Propagated",
       channel: "default/mortgage-channel"
     }
-  ]
+  ],
+  apiVersion: "app.k8s.io/v1beta1"
 };
 
 const query_data2 = {
@@ -211,7 +213,36 @@ describe("createApplicationLink", () => {
       _owner: null,
       _store: {},
       key: null,
-      props: { children: "val", replace: false, to: "undefined/default/val" },
+      props: {
+        children: [
+          {
+            _owner: null,
+            _store: {},
+            key: null,
+            props: {
+              align: "baseline",
+              children: {
+                _owner: null,
+                _store: {},
+                key: null,
+                props: {
+                  children: "val",
+                  replace: false,
+                  to: "undefined/default/val?apiVersion=app.k8s.io%2Fv1beta1"
+                },
+                ref: null
+              }
+            },
+            ref: null
+          },
+          false,
+          null
+        ],
+        hasGutter: true,
+        style: {
+          alignItems: "baseline"
+        }
+      },
       ref: null
     };
     expect(
